@@ -467,7 +467,7 @@ class Platform(object):
 class PythonVersion(object):
   """Class to validate the Python version we are using.
 
-  The Cloud CLI officially supports Python 3.8.
+  The Cloud CLI officially supports Python 3.9.
 
   However, many commands do work with Python 3.6, so we don't error out when
   users are using this (we consider it sometimes "compatible" but not
@@ -476,7 +476,7 @@ class PythonVersion(object):
 
   # See class docstring for descriptions of what these mean
   MIN_REQUIRED_PY3_VERSION = (3, 6)
-  MIN_SUPPORTED_PY3_VERSION = (3, 8)
+  MIN_SUPPORTED_PY3_VERSION = (3, 9)
   MAX_SUPPORTED_PY3_VERSION = (
       (3, 13)  # pylint: disable=g-long-ternary
       if encoding.GetEncodedValue(
@@ -484,9 +484,9 @@ class PythonVersion(object):
       )
       else (3, 13)
   )
-  UPCOMING_SUNSET_PY3_VERSION = (3, 8)
-  UPCOMING_PY3_MIN_SUPPORTED_VERSION = (3, 9)
-  UPCOMING_PY3_DEPRECATION_DATE = 'July 15th, 2025'
+  UPCOMING_SUNSET_PY3_VERSION = None
+  UPCOMING_PY3_MIN_SUPPORTED_VERSION = None
+  UPCOMING_PY3_DEPRECATION_DATE = None
   ENV_VAR_MESSAGE = """\
 
 If you have a compatible Python interpreter installed, you can use it by setting
